puppetlabs.puppetdb.nodes

OpenVox nodes parsing

Functions that handle conversion of nodes from wire format to internal OpenVoxDB format, including validation.

OpenVox nodes parsing

Functions that handle conversion of nodes from wire format to
internal OpenVoxDB format, including validation.
raw docstring

configure-expiration-wireformat-schemaclj

source

deactivate-node-wireformat-schemaclj

source

expire-wireformat-schemaclj

source

nodes-query->configure-expiration-wire-v1clj

(nodes-query->configure-expiration-wire-v1 nodes)

Inputs: [nodes :- [nodes-wireformat-schema]] Returns: [configure-expiration-wireformat-schema]

Inputs: [nodes :- [nodes-wireformat-schema]]
Returns: [configure-expiration-wireformat-schema]
sourceraw docstring

nodes-wireformat-schemaclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries